==> ask-sdk-2.12.0.tgz: package/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

# [2.12.0](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/compare/v2.11.0...v2.12.0) (2022-01-28)


### Bug Fixes

* updated node minimum versions for Github Actions and @types/node to fix test failures ([7636f36](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/commit/7636f3628b26af3fce0088105bb4b6738b9299c8))





# [2.11.0](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/compare/v2.10.2...v2.11.0) (2021-07-21)

**Note:** Version bump only for package ask-sdk





## [2.10.2](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/compare/v2.10.0...v2.10.2) (2021-03-16)

**Note:** Version bump only for package ask-sdk





# [2.10.0](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/compare/v2.9.0...v2.10.0) (2020-10-08)


### Bug Fixes

* fix the github action workflow and compilation making relative require fail issue ([#658](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/issues/658)) ([895c88e](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/commit/895c88e8bd875488a62966680a3d9d8eb2bcd9ea))
* update rootDir to point to the right root dir in tsconfig file in tst ([66ca284](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/commit/66ca284e13ed1dc881a13d69a399035eb4725e28))
* Updated all packages .npmignore files ([de76a18](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/commit/de76a18bcd21c6a411ddd72a09064e6d8b00c6ae))
* Updated all packages package.json ([#656](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/issues/656)) ([c27c3e6](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/commit/c27c3e6842834d0fea365613da7f3598955b558f))


### Features

* eslint migration and fixes, github actions workflows and updates on package.json for ask-sdk ([89560a6](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/commit/89560a6bf77f514fdb7a054a49654b20362b40f7))
* Update root package.json to fix doc generation ([4bf482b](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/commit/4bf482bb889fc9b93ad8d0afe8725862c5690f24))





# [2.9.0](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/compare/v2.8.0...v2.9.0) (2020-07-22)


### Bug Fixes

* general fix on some typo and lint issues ([#633](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/issues/633)) ([11ce407](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/commit/11ce407b7c52f4365d9d92b4358c50c9885a8a73))





# [2.8.0](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/compare/v2.7.0...v2.8.0) (2020-04-01)


### Bug Fixes

* Export LambdaHandler type definition ([#615](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/issues/615)) ([e4c2eaa](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/commit/e4c2eaa857537c82ac909c3be09bc52d9a74a035))
* extend tslint test to cover all test files ([#588](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/issues/588)) ([b142590](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/commit/b142590b2d07ff141e599ee63129d81c71aa0f1c))
* fixed one type definition and some doc issues  ([#583](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/issues/583)) ([5cc2576](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/commit/5cc257648a8aa6cbbaca65daac8a27d02ebbc89d))


### Features

* add new util function (getRequest) ([#582](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/issues/582)) ([a618ba9](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/commit/a618ba92c30d1ffb0590d21d8ee6cf7e1e11ac15))





# [2.7.0](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/compare/v2.6.0...v2.7.0) (2019-08-01)


### Bug Fixes

* export getUserId() at index.ts of both ask-sdk-core and ask-sdk([#561](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/issues/561)) ([b4b0980](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/commit/b4b0980))


### Features

* add appendAdditionalUserAgent function to customSkill in ask-sdk-core ([#575](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/issues/575)) ([7bbd7a6](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/commit/7bbd7a6))





# [2.6.0](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/compare/v2.5.2...v2.6.0) (2019-05-29)

**Note:** Version bump only for package ask-sdk





## [2.5.2](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/compare/v2.5.1...v2.5.2) (2019-04-24)

**Note:** Version bump only for package ask-sdk





## [2.5.1](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/compare/v2.5.0...v2.5.1) (2019-03-08)

**Note:** Version bump only for package ask-sdk





# [2.5.0](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/compare/v2.4.0...v2.5.0) (2019-03-07)


### Bug Fixes

* update peer dependency of ask-sdk-model ([#526](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/issues/526)) ([9167297](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/commit/9167297))


### Features

* add RequestEnvelopeUtils functions ([#525](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/issues/525)) ([14be7a8](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/commit/14be7a8))
* auto escape invalid SSML characters ([#522](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/issues/522)) ([7a4f215](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/commit/7a4f215)), closes [#472](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/issues/472)





# [2.4.0](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/compare/v2.3.0...v2.4.0) (2019-02-21)

**Note:** Version bump only for package ask-sdk





# [2.3.0](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/compare/v2.2.0...v2.3.0) (2018-11-05)

**Note:** Version bump only for package ask-sdk





# [2.2.0](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/compare/v2.1.0...v2.2.0) (2018-10-30)


### Features

* add support for Alexa Presentation Language (APL) ([bcdfec8](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/commit/bcdfec8))





<a name="2.1.0"></a>
# [2.1.0](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/compare/v2.0.10...v2.1.0) (2018-10-04)


### Features

* SDK structure update ([3f52c59](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/commit/3f52c59))




<a name="2.0.10"></a>
## [2.0.10](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/compare/v2.0.9...v2.0.10) (2018-09-25)




**Note:** Version bump only for package ask-sdk

<a name="2.0.9"></a>
## [2.0.9](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/compare/v2.0.8...v2.0.9) (2018-09-10)




**Note:** Version bump only for package ask-sdk

<a name="2.0.7"></a>
## [2.0.7](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/compare/v2.0.6...v2.0.7) (2018-06-22)


### Bug Fixes

* update attributes persistence behavior of ask-sdk-v1adapter ([51432df](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/commit/51432df)), closes [#414](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/issues/414)




<a name="2.0.6"></a>
## [2.0.6](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/compare/v2.0.5...v2.0.6) (2018-06-12)


### Bug Fixes

* make auto create table behavior more consistent ([fa826e4](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/commit/fa826e4))




<a name="2.0.5"></a>
## [2.0.5](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/compare/v2.0.4...v2.0.5) (2018-05-16)




**Note:** Version bump only for package ask-sdk

==> ask-sdk-2.12.1.tgz: package/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

## [2.12.1](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/compare/v2.12.0...v2.12.1) (2022-04-01)

**Note:** Version bump only for package ask-sdk





# [2.12.0](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/compare/v2.11.0...v2.12.0) (2022-01-28)


### Bug Fixes

* updated node minimum versions for Github Actions and @types/node to fix test failures ([7636f36](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/commit/7636f3628b26af3fce0088105bb4b6738b9299c8))





# [2.11.0](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/compare/v2.10.2...v2.11.0) (2021-07-21)

**Note:** Version bump only for package ask-sdk





## [2.10.2](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/compare/v2.10.0...v2.10.2) (2021-03-16)

**Note:** Version bump only for package ask-sdk





# [2.10.0](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/compare/v2.9.0...v2.10.0) (2020-10-08)


### Bug Fixes

* fix the github action workflow and compilation making relative require fail issue ([#658](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/issues/658)) ([895c88e](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/commit/895c88e8bd875488a62966680a3d9d8eb2bcd9ea))
* update rootDir to point to the right root dir in tsconfig file in tst ([66ca284](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/commit/66ca284e13ed1dc881a13d69a399035eb4725e28))
* Updated all packages .npmignore files ([de76a18](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/commit/de76a18bcd21c6a411ddd72a09064e6d8b00c6ae))
* Updated all packages package.json ([#656](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/issues/656)) ([c27c3e6](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/commit/c27c3e6842834d0fea365613da7f3598955b558f))


### Features

* eslint migration and fixes, github actions workflows and updates on package.json for ask-sdk ([89560a6](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/commit/89560a6bf77f514fdb7a054a49654b20362b40f7))
* Update root package.json to fix doc generation ([4bf482b](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/commit/4bf482bb889fc9b93ad8d0afe8725862c5690f24))





# [2.9.0](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/compare/v2.8.0...v2.9.0) (2020-07-22)


### Bug Fixes

* general fix on some typo and lint issues ([#633](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/issues/633)) ([11ce407](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/commit/11ce407b7c52f4365d9d92b4358c50c9885a8a73))





# [2.8.0](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/compare/v2.7.0...v2.8.0) (2020-04-01)


### Bug Fixes

* Export LambdaHandler type definition ([#615](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/issues/615)) ([e4c2eaa](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/commit/e4c2eaa857537c82ac909c3be09bc52d9a74a035))
* extend tslint test to cover all test files ([#588](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/issues/588)) ([b142590](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/commit/b142590b2d07ff141e599ee63129d81c71aa0f1c))
* fixed one type definition and some doc issues  ([#583](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/issues/583)) ([5cc2576](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/commit/5cc257648a8aa6cbbaca65daac8a27d02ebbc89d))


### Features

* add new util function (getRequest) ([#582](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/issues/582)) ([a618ba9](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/commit/a618ba92c30d1ffb0590d21d8ee6cf7e1e11ac15))





# [2.7.0](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/compare/v2.6.0...v2.7.0) (2019-08-01)


### Bug Fixes

* export getUserId() at index.ts of both ask-sdk-core and ask-sdk([#561](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/issues/561)) ([b4b0980](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/commit/b4b0980))


### Features

* add appendAdditionalUserAgent function to customSkill in ask-sdk-core ([#575](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/issues/575)) ([7bbd7a6](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/commit/7bbd7a6))





# [2.6.0](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/compare/v2.5.2...v2.6.0) (2019-05-29)

**Note:** Version bump only for package ask-sdk





## [2.5.2](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/compare/v2.5.1...v2.5.2) (2019-04-24)

**Note:** Version bump only for package ask-sdk





## [2.5.1](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/compare/v2.5.0...v2.5.1) (2019-03-08)

**Note:** Version bump only for package ask-sdk





# [2.5.0](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/compare/v2.4.0...v2.5.0) (2019-03-07)


### Bug Fixes

* update peer dependency of ask-sdk-model ([#526](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/issues/526)) ([9167297](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/commit/9167297))


### Features

* add RequestEnvelopeUtils functions ([#525](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/issues/525)) ([14be7a8](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/commit/14be7a8))
* auto escape invalid SSML characters ([#522](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/issues/522)) ([7a4f215](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/commit/7a4f215)), closes [#472](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/issues/472)





# [2.4.0](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/compare/v2.3.0...v2.4.0) (2019-02-21)

**Note:** Version bump only for package ask-sdk





# [2.3.0](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/compare/v2.2.0...v2.3.0) (2018-11-05)

**Note:** Version bump only for package ask-sdk





# [2.2.0](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/compare/v2.1.0...v2.2.0) (2018-10-30)


### Features

* add support for Alexa Presentation Language (APL) ([bcdfec8](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/commit/bcdfec8))





<a name="2.1.0"></a>
# [2.1.0](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/compare/v2.0.10...v2.1.0) (2018-10-04)


### Features

* SDK structure update ([3f52c59](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/commit/3f52c59))




<a name="2.0.10"></a>
## [2.0.10](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/compare/v2.0.9...v2.0.10) (2018-09-25)




**Note:** Version bump only for package ask-sdk

<a name="2.0.9"></a>
## [2.0.9](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/compare/v2.0.8...v2.0.9) (2018-09-10)




**Note:** Version bump only for package ask-sdk

<a name="2.0.7"></a>
## [2.0.7](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/compare/v2.0.6...v2.0.7) (2018-06-22)


### Bug Fixes

* update attributes persistence behavior of ask-sdk-v1adapter ([51432df](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/commit/51432df)), closes [#414](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/issues/414)




<a name="2.0.6"></a>
## [2.0.6](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/compare/v2.0.5...v2.0.6) (2018-06-12)


### Bug Fixes

* make auto create table behavior more consistent ([fa826e4](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/commit/fa826e4))




<a name="2.0.5"></a>
## [2.0.5](https://github.com/alexa/alexa-skills-kit-sdk-for-nodejs/compare/v2.0.4...v2.0.5) (2018-05-16)




**Note:** Version bump only for package ask-sdk
